@@ -33,6 +33,56 @@ class TestUploadTokensApi(MainTest):
         super().setUp()
         self.api = UploadTokensApi(self.client)  # noqa: E501
 
+    @responses.activate
+    def test_create_token(self):
+        """Test case for create_token
+
+        Generate an upload token  # noqa: E501
+        """
+        for status, json in self.load_json('upload_tokens', 'create_token'):
+            responses.reset()
+
+            kwargs = {
+                'token_creation_payload': TokenCreationPayload(
+        ttl=0,
+    ),
+            }
+            url = '/upload-tokens'.format(**kwargs)
+
+            responses.add('POST', url, body=json, status=int(status), content_type='application/json')
+
+            if status[0] == '4':
+                with self.assertRaises(ApiException) as context:
+                    self.api.create_token(**kwargs)
+                if status == '404':
+                    self.assertIsInstance(context.exception, NotFoundException)
+            else:
+                self.api.create_token(**kwargs)
+
+    @responses.activate
+    def test_get_token(self):
+        """Test case for get_token
+
+        Retrieve upload token  # noqa: E501
+        """
+        for status, json in self.load_json('upload_tokens', 'get_token'):
+            responses.reset()
+
+            kwargs = {
+                'upload_token': "to1tcmSFHeYY5KzyhOqVKMKb",
+            }
+            url = '/upload-tokens/{upload_token}'.format(**kwargs)
+
+            responses.add('GET', url, body=json, status=int(status), content_type='application/json')
+
+            if status[0] == '4':
+                with self.assertRaises(ApiException) as context:
+                    self.api.get_token(**kwargs)
+                if status == '404':
+                    self.assertIsInstance(context.exception, NotFoundException)
+            else:
+                self.api.get_token(**kwargs)
+
     @responses.activate
     def test_delete_token(self):
         """Test case for delete_token
@@ -64,53 +114,3 @@ class TestUploadTokensApi(MainTest):
             else:
                 self.api.list(**kwargs)
 
-    @responses.activate
-    def test_get_token(self):
-        """Test case for get_token
-
-        Show upload token  # noqa: E501
-        """
-        for status, json in self.load_json('upload_tokens', 'get_token'):
-            responses.reset()
-
-            kwargs = {
-                'upload_token': "to1tcmSFHeYY5KzyhOqVKMKb",
-            }
-            url = '/upload-tokens/{upload_token}'.format(**kwargs)
-
-            responses.add('GET', url, body=json, status=int(status), content_type='application/json')
-
-            if status[0] == '4':
-                with self.assertRaises(ApiException) as context:
-                    self.api.get_token(**kwargs)
-                if status == '404':
-                    self.assertIsInstance(context.exception, NotFoundException)
-            else:
-                self.api.get_token(**kwargs)
-
-    @responses.activate
-    def test_create_token(self):
-        """Test case for create_token
-
-        Generate an upload token  # noqa: E501
-        """
-        for status, json in self.load_json('upload_tokens', 'create_token'):
-            responses.reset()
-
-            kwargs = {
-                'token_creation_payload': TokenCreationPayload(
-        ttl=0,
-    ),
-            }
-            url = '/upload-tokens'.format(**kwargs)
-
-            responses.add('POST', url, body=json, status=int(status), content_type='application/json')
-
-            if status[0] == '4':
-                with self.assertRaises(ApiException) as context:
-                    self.api.create_token(**kwargs)
-                if status == '404':
-                    self.assertIsInstance(context.exception, NotFoundException)
-            else:
-                self.api.create_token(**kwargs)
-
